import { Device, Target } from "./device";
import { Texture, TextureColorInternalFormat as ColorFormat, TextureDepthInternalFormat as DepthFormat, TextureDepthStencilInternalFormat as DepthStencilFormat } from "./texture";
export declare class Framebuffer {
    /**
     * Create a framebuffer containg one or more color buffers with given
     * width and height.
     */
    static withColor(dev: Device, width: number, height: number, color: Texture<ColorFormat> | Texture<ColorFormat>[]): Framebuffer;
    /**
     * Create a framebuffer containg a depth buffer with given width and height.
     */
    static withDepth(dev: Device, width: number, height: number, depth: Texture<DepthFormat>): Framebuffer;
    /**
     * Create a framebuffer containg a depth-stencil buffer with given
     * width and height.
     */
    static withDepthStencil(dev: Device, width: number, height: number, depthStencil: Texture<DepthStencilFormat>): Framebuffer;
    /**
     * Create a framebuffer containg one or more color buffers and a depth
     * buffer with given width and height.
     */
    static withColorDepth(dev: Device, width: number, height: number, color: Texture<ColorFormat> | Texture<ColorFormat>[], depth: Texture<DepthFormat>): Framebuffer;
    /**
     * Create a framebuffer containg one or more color buffers and a
     * depth-stencil buffer with given width and height.
     */
    static withColorDepthStencil(dev: Device, width: number, height: number, color: Texture<ColorFormat> | Texture<ColorFormat>[], depthStencil: Texture<DepthStencilFormat>): Framebuffer;
    readonly width: number;
    readonly height: number;
    readonly glFramebuffer: WebGLFramebuffer | null;
    private gl;
    private glColorAttachments;
    private framebufferTarget;
    private colors;
    private depthStencil?;
    private depthOnly;
    private constructor();
    /**
     * Force framebuffer reinitialization.
     */
    init(): void;
    /**
     * Reinitialize invalid framebuffer, eg. after context is lost.
     */
    restore(): void;
    /**
     * Request a render target from this framebuffer to draw into. The target
     * will contain all attached color buffers.
     *
     * Drawing should be done within the callback by
     * calling `ratget.clear()` or `target.draw()` family of methods.
     *
     * Also see `device.target()`.
     */
    target(cb: (rt: Target) => void): void;
}
